@@ -1,4 +1,5 @@
 """pytest-asyncio implementation."""
+
 import asyncio
 import contextlib
 import enum
@@ -115,8 +116,7 @@ def fixture(
         None,
     ] = ...,
     name: Optional[str] = ...,
-) -> FixtureFunction:
-    ...
+) -> FixtureFunction: ...
 
 
 @overload
@@ -132,8 +132,7 @@ def fixture(
         None,
     ] = ...,
     name: Optional[str] = None,
-) -> FixtureFunctionMarker:
-    ...
+) -> FixtureFunctionMarker: ...
 
 
 def fixture(
@@ -558,6 +557,10 @@ _fixture_scope_by_collector_type = {
     Session: "session",
 }
 
+# A stack used to push package-scoped loops during collection of a package
+# and pop those loops during collection of a Module
+__package_loop_stack: List[Union[FixtureFunctionMarker, FixtureFunction]] = []
+
 
 @pytest.hookimpl
 def pytest_collectstart(collector: pytest.Collector):
@@ -608,7 +611,13 @@ def pytest_collectstart(collector: pytest.Collector):
     # know it exists. We work around this by attaching the fixture function to the
     # collected Python object, where it will be picked up by pytest.Class.collect()
     # or pytest.Module.collect(), respectively
-    if type(collector) is Module:
+    if type(collector) is Package:
+        # Packages do not have a corresponding Python object. Therefore, the fixture
+        # for the package-scoped event loop is added to a stack. When a module inside
+        # the package is collected, the module will attach the fixture to its
+        # Python object.
+        __package_loop_stack.append(scoped_event_loop)
+    elif isinstance(collector, Module):
         # Accessing Module.obj triggers a module import executing module-level
         # statements. A module-level pytest.skip statement raises the "Skipped"
         # OutcomeException or a Collector.CollectError, if the "allow_module_level"
@@ -617,28 +626,21 @@ def pytest_collectstart(collector: pytest.Collector):
         # Therefore, we monkey patch Module.collect to add the scoped fixture to the
         # module before it runs the actual collection.
         def _patched_collect():
-            collector.obj.__pytest_asyncio_scoped_event_loop = scoped_event_loop
+            # If the collected module is a DoctestTextfile, collector.obj is None
+            module = collector.obj
+            if module is not None:
+                module.__pytest_asyncio_scoped_event_loop = scoped_event_loop
+                try:
+                    package_loop = __package_loop_stack.pop()
+                    module.__pytest_asyncio_package_scoped_event_loop = package_loop
+                except IndexError:
+                    pass
             return collector.__original_collect()
 
         collector.__original_collect = collector.collect
         collector.collect = _patched_collect
-    else:
-        pyobject = collector.obj
-        # If the collected module is a DoctestTextfile, collector.obj is None
-        if pyobject is None:
-            return
-        pyobject.__pytest_asyncio_scoped_event_loop = scoped_event_loop
-    # When collector is a package, collector.obj is the package's __init__.py.
-    # pytest doesn't seem to collect fixtures in __init__.py.
-    # Using parsefactories to collect fixtures in __init__.py their baseid will end
-    # with "__init__.py", thus limiting the scope of the fixture to the init module.
-    # Therefore, we tell the pluginmanager explicitly to collect the fixtures
-    # in the init module, but strip "__init__.py" from the baseid
-    # Possibly related to https://github.com/pytest-dev/pytest/issues/4085
-    if isinstance(collector, Package):
-        fixturemanager = collector.config.pluginmanager.get_plugin("funcmanage")
-        package_node_id = _removesuffix(collector.nodeid, "__init__.py")
-        fixturemanager.parsefactories(collector.obj, nodeid=package_node_id)
+    elif isinstance(collector, Class):
+        collector.obj.__pytest_asyncio_scoped_event_loop = scoped_event_loop
 
 
 def _removesuffix(s: str, suffix: str) -> str:
@@ -717,9 +719,9 @@ def pytest_generate_tests(metafunc: Metafunc) -> None:
         # The fixture needs to be appended to avoid messing up the fixture evaluation
         # order
         metafunc.fixturenames.append(event_loop_fixture_id)
-        metafunc._arg2fixturedefs[
-            event_loop_fixture_id
-        ] = fixturemanager._arg2fixturedefs[event_loop_fixture_id]
+        metafunc._arg2fixturedefs[event_loop_fixture_id] = (
+            fixturemanager._arg2fixturedefs[event_loop_fixture_id]
+        )
 
 
 @pytest.hookimpl(hookwrapper=True)
